Callable Serialization Example
================================

This example demonstrates serializing and deserializing callable objects (functions, methods, and lambda expressions).

.. literalinclude:: ../../../examples/callable_serialization.py
   :language: python
   :linenos:

